import copy
from typing import List, Optional, Union

from common.backend.models.base import RAGImage, Source


def get_rag_images_full_data(images: Union[List[RAGImage], List[str]]) -> List[RAGImage]:
    from dataiku.langchain.metadata_handler import ImageRetrieval, MetadataHandler
    output: List[RAGImage] =  []
    for image in images:
        if isinstance(image, dict):
            document_info = {"content": image.get("file_path")}
            full_folder_id = image.get("full_folder_id")
            index = image.get("index")
            image_retrieval = ImageRetrieval.IMAGE_INLINE
            parts = MetadataHandler._get_image_parts(document_info, full_folder_id, index, image_retrieval)
            if parts and len(parts) > 0:
                image_copy = copy.deepcopy(image)
                image_copy["file_data"] = f"data:image/png;base64,{parts[0].inline_image}"
                output.append(image_copy)
                # Shouldn't happend
                for part in parts[1:]:
                    output.append({"file_data": f"data:image/png;base64,{part.inline_image}"})
        else:
            # Here we handle legacy
            output.append({"file_data": image})
    return output

def get_sources_to_store(sources: Optional[List[Source]]):
    # Do not store images data in db
    # Only store info of images to be loaded later
    sources_copy = []
    if sources:
        sources_copy = copy.deepcopy(sources)
        for source in sources_copy:
            if source.get("images"):
                for image in source["images"] or []:
                    image.pop("file_data", None)
    return sources_copy
